@@ -98,7 +98,7 @@ create_marker_layer (G_GNUC_UNUSED ChamplainView *view, ChamplainPathLayer **pat
 	gchar *station = NULL, *station_link;
 	VoiceInfo *voinfo = gnome_voice_file_loader (voinfo, voice_filename);
 	*path = champlain_path_layer_new ();
-	// champlain_path_layer_set_stroke_color(path, &city_color);
+	champlain_path_layer_set_stroke_color(path, &city_color);
 	layer = champlain_marker_layer_new_full (CHAMPLAIN_SELECTION_SINGLE);
 	layer_actor = CLUTTER_ACTOR (layer);	
 	while (voinfo != NULL) {
@@ -524,7 +524,6 @@ static void gv_wizard_button_clicked(GtkButton * button,
 	GDateTime *datestamp = g_date_time_new_now_utc ();
 	GstElementFactory *factory;
 	GTimeVal *timeval;
-
 	gst_element_send_event(recorder, gst_event_new_eos());
 	recorder = gst_pipeline_new("record_pipe");
 	/*
@@ -559,11 +558,10 @@ static void gv_wizard_button_clicked(GtkButton * button,
                                  GST_TAG_TITLE, gtk_entry_get_text(GTK_ENTRY(title_entry)),
                                  GST_TAG_ARTIST, g_get_real_name(),
                                  GST_TAG_ALBUM, "Voicegrams",
-                                 GST_TAG_COMMENT, "GNOME 45",
+                                 GST_TAG_COMMENT, "GNOME 44",
                                  GST_TAG_DATE, g_date_time_format_iso8601 (datestamp),
                                  NULL);
 	g_date_time_unref (datestamp);
-
 	main_loops = g_main_loop_new(NULL, TRUE);
 	g_main_loop_run(main_loops);
 	gst_element_set_state(recorder, GST_STATE_NULL);
@@ -608,13 +606,11 @@ static void gv_wizard_close(GtkAssistant * assistant, gpointer data)
 	g_date_strftime (timebuffer, sizeof (timebuffer), "%s", &d);
 	session = soup_session_sync_new ();
 	voice_pointer = fopen(filename_voice, "w");
-	fprintf(voice_pointer, "<?xml version=\"1.0\"?>\n");	
 	fprintf(voice_pointer, "<voice version='%s'>\n", VERSION);
-	fprintf(voice_pointer, "  <station name='%s' uri='http://%s/~%s/GNOME.voice'>\n",
+	fprintf(voice_pointer, "  <station name='%s' uri='http://%s/GNOME.ogg'>\n",
 		g_get_real_name(),
-		g_get_host_name(),
-		g_get_user_name());
-	fprintf(voice_pointer, "    <location lat='%9.7f' lon='%9.7f'>%s</location>\n", lat_gps, lon_gps, g_get_host_name());
+		g_get_host_name());
+	fprintf(voice_pointer, "    <location lat='%10.7f' lon='%9.7f'>%s</location>\n", lat_gps, lon_gps, g_get_host_name());
 	fprintf(voice_pointer, "    <stream>https://www.gnomevoice.org/stream/data/%s%s</stream>\n", timebuffer, ".voice");
 	fprintf(voice_pointer, "  </station>\n");
 	fprintf(voice_pointer, "</voice>\n");
@@ -624,13 +620,13 @@ static void gv_wizard_close(GtkAssistant * assistant, gpointer data)
 	soup_message_set_request (msg, "application/xml",
 				  SOUP_MEMORY_COPY,
 				  g_strconcat(g_strconcat("<voice version='", VERSION, "'>\n", NULL),
-					      g_strconcat("  <station name='", g_get_real_name(), "' uri='http://", g_get_host_name(), "/~", g_get_user_name(), "/GNOME.voice'>\n", NULL),
+					      g_strconcat("  <station name='", g_get_real_name(), "' uri='http://", g_get_host_name(), "/GNOME.ogg'>\n", NULL),
 					      g_strconcat("    <location lat='%10.7f' lon='%9.7f'>%s</location>\n", lat_gps, lon_gps, g_get_host_name(), NULL),
 					      g_strconcat("    <stream>https://www.gnomevoice.org/stream/data/%s%s</stream>\n", timebuffer, ".voice", NULL),
 					      g_strconcat("  </station>\n", NULL),
 					      g_strconcat("</voice>\n", NULL),NULL),
 				  strlen(g_strconcat(g_strconcat("<voice version='", VERSION, "'>\n", NULL),
-						     g_strconcat("  <station name='", g_get_real_name(), "' uri='http://", g_get_host_name(), "/~", g_get_user_name(), "/GNOME.voice'>\n", NULL),
+						     g_strconcat("  <station name='", g_get_real_name(), "' uri='http://", g_get_host_name(), "/GNOME.ogg'>\n", NULL),
 						     g_strconcat("    <location lat='%10.7f' lon='%9.7f'>%s</location>\n", lat_gps, lon_gps, g_get_host_name(), NULL),
 						     g_strconcat("    <stream>https://www.gnomevoice.org/stream/data/%s%s</stream>\n", timebuffer, ".voice", NULL),
 						     g_strconcat("  </station>\n", NULL),
@@ -646,6 +642,7 @@ static void gv_wizard_close(GtkAssistant * assistant, gpointer data)
                 g_main_loop_quit(loop);
 		gtk_main_quit();
         }
+	/* gst_element_send_event(data, gst_event_new_eos()); */
 }
 
 static void gv_wizard_apply(GtkAssistant * assistant, gpointer data)
@@ -698,9 +695,9 @@ main (gint argc, gchar **argv)
 	GtkWidget *introduction;
 	int i = 0;
 	PageInfo page[5] = {
-		{NULL, -1, "Voice 1.8.0", GTK_ASSISTANT_PAGE_INTRO, TRUE},
+		{NULL, -1, "Voice 2.0.0", GTK_ASSISTANT_PAGE_INTRO, TRUE},
 		{NULL, -1, "Voicegram", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
-		{NULL, -1, "Home Page", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
+		{NULL, -1, "Filename", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Summary", GTK_ASSISTANT_PAGE_SUMMARY, TRUE},		
 		{NULL, -1, "Finish", GTK_ASSISTANT_PAGE_CONFIRM, TRUE},
 	};
@@ -722,7 +719,7 @@ main (gint argc, gchar **argv)
 	  fprintf(stderr, "No Voice Stream typed on the command line\n");
 	}
 
-	context = g_option_context_new ("- Voice 1.8.0");
+	context = g_option_context_new ("- Voice 2.0.0");
 	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	if (!g_option_context_parse (context, &argc, &argv, &error)) {
@@ -735,10 +732,10 @@ main (gint argc, gchar **argv)
 	introduction = gtk_assistant_new();
 	gtk_container_add (GTK_WINDOW (window), introduction);
 	gtk_widget_set_size_request(GTK_WIDGET(introduction), 640, 480);
-	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 1.8.0");
+	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 2.0.0");
 	g_signal_connect(G_OBJECT(introduction), "destroy",
 			 G_CALLBACK(gtk_main_quit), NULL);
-	page[0].widget = gtk_label_new(_("Welcome to Voice 1.8.0!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
+	page[0].widget = gtk_label_new(_("Welcome to Voice 2.0.0!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
 	page[1].widget = gtk_box_new(FALSE, 5);
 	title_label = gtk_label_new(_("Voicegram:"));
 	title_entry = gtk_entry_new();
@@ -749,10 +746,9 @@ main (gint argc, gchar **argv)
 	gtk_box_pack_start(GTK_BOX(page[1].widget), GTK_WIDGET(title_entry),
 			   FALSE, FALSE, 5);
 	page[2].widget = gtk_box_new(FALSE, 5);
-
-	filename_label = gtk_label_new(_("Home Page:"));
+	filename_label = gtk_label_new(_("Filename:"));
 	filename_entry = gtk_entry_new();
-	if (g_strcmp0(filename_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(filename_entry), g_strconcat ("http://", g_get_host_name(), "/~", g_get_user_name(), "/GNOME.voice", NULL)); else gtk_entry_set_text(GTK_ENTRY(filename_entry), gtk_entry_get_text(GTK_ENTRY(filename_entry)));
+	if (g_strcmp0(filename_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(filename_entry), g_strconcat ("GNOME.ogg", NULL)); else gtk_entry_set_text(GTK_ENTRY(filename_entry), gtk_entry_get_text(GTK_ENTRY(filename_entry)));
 	gtk_box_pack_start(GTK_BOX(page[2].widget), GTK_WIDGET(filename_label),
 			   FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[2].widget), GTK_WIDGET(filename_entry),
@@ -795,8 +791,8 @@ main (gint argc, gchar **argv)
 	g_signal_connect(G_OBJECT(introduction), "apply",
 			 G_CALLBACK(gv_wizard_close), pipeline);
 	gtk_widget_show_all (GTK_WIDGET (introduction));
-#if 0
 	gst_init(&argc, &argv);
+	gst_init(NULL, NULL);
 	pipeline = gst_pipeline_new("record_pipe");
 
 	src = gst_element_factory_make("autoaudiosrc", "auto_source");
@@ -804,7 +800,7 @@ main (gint argc, gchar **argv)
 	enc = gst_element_factory_make("vorbisenc", "vorbis_enc");
 	muxer = gst_element_factory_make("oggmux", "oggmux");
 	sink = gst_element_factory_make("filesink", "sink");
-	filename = g_strconcat(gtk_entry_get_text(filename_entry), NULL);
+	filename = g_strconcat("file://", g_get_host_name(), g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), gtk_entry_get_text(filename_entry), NULL);
 	g_object_set(G_OBJECT(sink), "location",
 		     g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/", gtk_entry_get_text(filename_entry), NULL));
 	gst_bin_add_many(GST_BIN(pipeline), src, conv, enc, muxer, sink, NULL);
@@ -817,16 +813,14 @@ main (gint argc, gchar **argv)
 				 GST_TAG_TITLE, g_get_real_name(),
 				 GST_TAG_ARTIST, g_get_real_name(),
 				 GST_TAG_ALBUM, gtk_entry_get_text(filename_entry),
-				 GST_TAG_COMMENT, "Voice 1.8.0",
+				 GST_TAG_COMMENT, "Voice 2.0.0",
 				 GST_TAG_DATE, g_date_time_format_iso8601 (datestamp),
 				 NULL);
 	g_date_time_unref (datestamp);
-#endif
 	main_loops = g_main_loop_new(NULL, TRUE);
   
 	if (clutter_init (&argc, &argv) != CLUTTER_INIT_SUCCESS)
 		return 1;
-
 	/* vosc = (VOSCWindow *)g_new0(VOSCWindow, 1); */
 	stage = clutter_stage_new ();
 
@@ -893,7 +887,6 @@ main (gint argc, gchar **argv)
         /* oscilloscope_data.oscilloscope_visual = GNOME_VOICE_MARKER (oscilloscope_visual); */
 	/* Create the voice player */
 	player = gst_player_new (NULL, gst_player_g_main_context_signal_dispatcher_new(NULL));
-	voiceinfo->stream->uri = gtk_entry_get_text(GTK_ENTRY(filename_entry));
 	gst_player_set_uri (GST_PLAYER (player), voiceinfo->stream->uri);
 	gst_player_play(GST_PLAYER (player));
 	gst_player_set_uri (GST_PLAYER (player), voice_stream);
