@@ -3,10 +3,10 @@
 
 #include <geoclue.h>
 
-double lat = 68.1841843;
-double lon = 15.5974169;
-double lat_gps = 68.1841843;
-double lon_gps = 15.5974169;
+double lat = 0;
+double lon = 0;
+double lat_gps = 0;
+double lon_gps = 0;
 
 typedef struct
 {
